@@ -244,7 +244,7 @@ func TestProxyArgs(t *testing.T) {
 	val, _, _ = uns.NestedString(cfg.Object, "bindAddress")
 	g.Expect(val).To(Equal("1.2.3.4"))
 
-	//set proxy args
+	// set proxy args
 	config.KubeProxyConfig.ProxyArguments = map[string]operv1.ProxyArgumentList{
 		"cluster-cidr":       {"1.2.3.4/5"},
 		"config-sync-period": {"1s", "2s"},
@@ -280,6 +280,32 @@ func TestProxyArgs(t *testing.T) {
 	arg, _, _ = uns.NestedString(cfg.Object, "mode")
 	g.Expect(arg).To(Equal("iptables"))
 
+	// Explicitly setting the metrics port to "9101" is allowed but does not affect
+	// the actual configuration, which uses "29101". Other port values are not
+	// allowed. (Even 29101!)
+	config.KubeProxyConfig.ProxyArguments = map[string]operv1.ProxyArgumentList{
+		"metrics-port": {"29101"},
+	}
+	errs := validateKubeProxy(config)
+	g.Expect(errs).To(HaveLen(1))
+	config.KubeProxyConfig.ProxyArguments = map[string]operv1.ProxyArgumentList{
+		"metrics-port": {"9101"},
+	}
+	errs = validateKubeProxy(config)
+	g.Expect(errs).To(HaveLen(0))
+	// Validate that we don't allow the feature-gates to be set via user config
+	config.KubeProxyConfig.ProxyArguments = map[string]operv1.ProxyArgumentList{
+		"feature-gates": {"FGBar=baz"},
+	}
+	errs = validateKubeProxy(config)
+	g.Expect(errs).To(HaveLen(1))
+
+	objs, err = renderOpenShiftSDN(config, manifestDir)
+	g.Expect(err).NotTo(HaveOccurred())
+	cfg = getProxyConfigFile(objs)
+
+	arg, _, _ = uns.NestedString(cfg.Object, "metricsBindAddress")
+	g.Expect(arg).To(Equal("0.0.0.0:29101"))
 }
 
 func TestOpenShiftSDNIsSafe(t *testing.T) {
@@ -398,6 +424,7 @@ func TestOpenshiftSDNProxyConfig(t *testing.T) {
 	g.Expect(getProxyConfig(objs)).To(MatchYAML(`
 apiVersion: kubeproxy.config.k8s.io/v1alpha1
 bindAddress: 0.0.0.0
+bindAddressHardFail: false
 clientConnection:
   acceptContentTypes: ""
   burst: 0
@@ -413,6 +440,9 @@ conntrack:
   tcpEstablishedTimeout: null
 detectLocalMode: ""
 enableProfiling: false
+featureGates:
+  EndpointSlice: false
+  EndpointSliceProxying: false
 healthzBindAddress: 0.0.0.0:10256
 hostnameOverride: ""
 iptables:
@@ -451,6 +481,7 @@ winkernel:
 	g.Expect(getProxyConfig(objs)).To(MatchYAML(`
 apiVersion: kubeproxy.config.k8s.io/v1alpha1
 bindAddress: 0.0.0.0
+bindAddressHardFail: false
 clientConnection:
   acceptContentTypes: ""
   burst: 0
@@ -466,6 +497,9 @@ conntrack:
   tcpEstablishedTimeout: null
 detectLocalMode: ""
 enableProfiling: false
+featureGates:
+  EndpointSlice: false
+  EndpointSliceProxying: false
 healthzBindAddress: 0.0.0.0:10256
 hostnameOverride: ""
 iptables:
